==> darklaf-utils-2.5.4-sources.jar: com/github/weisj/darklaf/util/FontUtil.java <==
/*
 * MIT License
 *
 * Copyright (c) 2020 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.darklaf.util;

import java.awt.*;

import javax.swing.*;
import javax.swing.text.StyleContext;


public class FontUtil {

    public static Font createFont(final String family, final int style, final int size) {
        // This method calls FontUtilities.getCompositeFontUIResource(Font) internally which
        // creates a composite font with fallback support.
        return new NonUIResourceFont(StyleContext.getDefaultStyleContext().getFont(family, style, size));
    }

    public static int getCenteredFontPosition(final int height, final FontMetrics fm) {
        int asc = fm.getMaxAscent();
        int y = (height - asc) / 2;
        y -= fm.getDescent() / 2;
        return y;
    }

    public static class NonUIResourceFont extends Font {

        public NonUIResourceFont(final Font font) {
            super(font);
        }
    }
}

==> darklaf-utils-2.7.3-sources.jar: com/github/weisj/darklaf/util/FontUtil.java <==
/*
 * MIT License
 *
 * Copyright (c) 2021 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.darklaf.util;

import java.awt.*;

import javax.swing.*;
import javax.swing.text.StyleContext;


public final class FontUtil {

    public static Font createFont(final String family, final int style, final int size) {
        // This method calls FontUtilities.getCompositeFontUIResource(Font) internally which
        // creates a composite font with fallback support.
        return new NonUIResourceFont(StyleContext.getDefaultStyleContext().getFont(family, style, size));
    }

    public static int getCenteredFontPosition(final int height, final FontMetrics fm) {
        int asc = fm.getMaxAscent();
        int y = (height - asc) / 2;
        y -= fm.getDescent() / 2;
        return y;
    }

    public static class NonUIResourceFont extends Font {

        public NonUIResourceFont(final Font font) {
            super(font);
        }
    }
}
